# CENdetectHOR Library (cen_detect_hor)

[![PyPI - Version](https://img.shields.io/pypi/v/cen_detect_hor.svg)](https://pypi.org/project/cen_detect_hor)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cen_detect_hor.svg)](https://pypi.org/project/cen_detect_hor)

Library to characterise tandem repeats in genomic sequences in terms of evolutionary relationships, looking for so called higher-order-repeats (HORs).
It has been specifically designed to analyse non-coding centromeric high-repetition regions of chromosomes. 

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install cen_detect_hor
```

## License

`cen_detect_hor` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
